"use strict";

Object.defineProperty(exports, "__esModule", {
  value: true
});
exports.getFixtures2 = getFixtures2;

var _path = _interopRequireDefault(require("path"));

var _FixtureLoader = require("react-cosmos-shared2/FixtureLoader");

var _fixtureTree = require("react-cosmos-shared2/fixtureTree");

var _react = require("react-cosmos-shared2/react");

var _url = require("react-cosmos-shared2/url");

var _playgroundHtml = require("./shared/playgroundHtml");

var _userDeps = require("./shared/userDeps");

function _interopRequireDefault(obj) { return obj && obj.__esModule ? obj : { default: obj }; }

function getFixtures2(_ref) {
  var cosmosConfig = _ref.cosmosConfig;
  var fixturesDir = cosmosConfig.fixturesDir,
      fixtureFileSuffix = cosmosConfig.fixtureFileSuffix,
      rootDir = cosmosConfig.rootDir;
  var host = getPlaygroundHost(cosmosConfig);
  var fixtureInfo = [];

  var _getUserModules = (0, _userDeps.getUserModules)(cosmosConfig),
      fixtureExportsByPath = _getUserModules.fixtureExportsByPath,
      decoratorsByPath = _getUserModules.decoratorsByPath;

  var fixtureNamesByPath = (0, _react.getFixtureNamesByPath)(fixtureExportsByPath);
  var fixtureTree = (0, _fixtureTree.createFixtureTree)({
    fixtures: fixtureNamesByPath,
    fixturesDir: fixturesDir,
    fixtureFileSuffix: fixtureFileSuffix
  });
  var flatFixtureTree = (0, _fixtureTree.flattenFixtureTree)(fixtureTree);
  flatFixtureTree.forEach(function (_ref2) {
    var fixtureId = _ref2.fixtureId,
        cleanPath = _ref2.cleanPath;
    var rawFileName = fixtureId.path.split('/').pop();
    var cleanFileName = (0, _fixtureTree.removeFixtureNameSuffix)((0, _fixtureTree.removeFixtureNameExtension)(rawFileName), fixtureFileSuffix);
    var fixtureExport = fixtureExportsByPath[fixtureId.path];
    var fixture = fixtureId.name === null ? fixtureExport : fixtureExport[fixtureId.name];
    fixtureInfo.push({
      absoluteFilePath: _path.default.join(rootDir, fixtureId.path),
      fileName: cleanFileName,
      getElement: createFixtureElementGetter(fixture, fixtureId.path, decoratorsByPath),
      name: fixtureId.name,
      relativeFilePath: fixtureId.path,
      playgroundUrl: getRendererUrl(host, fixtureId),
      rendererUrl: getPlaygroundUrl(host, fixtureId),
      treePath: cleanPath
    });
  });
  return fixtureInfo;
}

function getPlaygroundUrl(host, fixtureId) {
  var query = (0, _url.stringifyPlaygroundUrlQuery)({
    fixtureId: fixtureId
  });
  return "".concat(host, "/?").concat(query);
}

function getRendererUrl(host, fixtureId) {
  var query = (0, _url.stringifyRendererUrlQuery)({
    _fixtureId: fixtureId
  });
  return "".concat(host, "/").concat(_playgroundHtml.RENDERER_FILENAME, "?").concat(query);
}

function getPlaygroundHost(_ref3) {
  var hostname = _ref3.hostname,
      port = _ref3.port;
  return "http://".concat(hostname || 'localhost', ":").concat(port);
}

function createFixtureElementGetter(fixture, fixturePath, decoratorsByPath) {
  var decorators = (0, _react.getSortedDecoratorsForFixturePath)(fixturePath, decoratorsByPath);
  return function () {
    return (0, _FixtureLoader.getDecoratedFixtureElement)(fixture, decorators, {
      fixtureState: {},
      setFixtureState: function setFixtureState() {},
      onErrorReset: function onErrorReset() {}
    });
  };
}